#
# spec file for package python-tqdm
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
%global flavor %{nil}
%if "%{flavor}" == "test"
%define test 1
%define pkg_suffix -test
%bcond_without test
%else
%define pkg_suffix %{nil}
%bcond_with test
%endif
Name:           python-tqdm%{pkg_suffix}
Version:        4.45.0
Release:        bp155.2.14
Summary:        An extensible progress meter
License:        MPL-2.0 AND MIT
URL:            https://github.com/tqdm/tqdm
Source:         https://files.pythonhosted.org/packages/source/t/tqdm/tqdm-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module tqdm}
BuildRequires:  python3-ipython
BuildRequires:  python3-ipywidgets
# /SECTION
%endif
%python_subpackages

%description
tqdm lets you output a progress meter from within loops by wrapping
any iterable with "tqdm(iterable)".
tqdm's overhead is one order of magnitude less than python-progressbar
and does not require ncurses.

%prep
%setup -q -n tqdm-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_clone -a %{buildroot}%{_bindir}/tqdm
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if !%{with test}
%post
%{python_install_alternative tqdm tqdm.1}

%postun
%python_uninstall_alternative tqdm
%endif

%if %{with test}
%check
%{python_expand PYTHONPATH=%{$python_sitelib}
nosetests-%%{$python_bin_suffix} --ignore-files="tests_perf\.py" --ignore-files="tests_synchronisation\.py" tqdm/
}
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst logo.png
%doc examples/
%license LICENCE
%{python_sitelib}/tqdm/
%{python_sitelib}/tqdm-%{version}-py*.egg-info
%python_alternative %{_bindir}/tqdm
%endif

%changelog
* Wed Apr  8 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 4.45.0:
  * propagate and close() on exceptions (#926 <- #548)
  * fix nested clear()
  * rework nested close() (#930 <- #924 <- #918, #677)
  * update all documentation & demos
  * add and update tests
  * dev framework: add pre-commit helper
  * fix _utils ImportError => DeprecationWarning
* Sat Feb 22 2020 Arun Persaud <arun@gmx.de>
- update to version 4.43.0:
  * fix notebook exceptions (#669 <- #650)
    + set_description() when disable=True
  * contrib.concurrent: avoid unnecessary len(iterable) (#893)
  * update documentation
    + clarify etymology (#895)
    + fix minor typo (#890)
    + update contributors and years
  * update tests
  * fix CI tests for PRs
* Sun Feb  9 2020 Arun Persaud <arun@gmx.de>
- update to version 4.42.1:
  * support pandas==1.0.0 (#780, #555)
  * minor metadata updates
  * minor CI test update
* Sun Jan 26 2020 Arun Persaud <arun@gmx.de>
- update to version 4.42.0:
  * notebook: update disable=None behaviour (#880)
  * tqdm.keras: support tensorflow.keras as well as keras (#885)
  * add contrib (#882)
    + tenumerate (#840 <- #480, #402)
    + tzip <= zip
    + tmap <= map
    + add concurrent module
    o thread_map <= concurrent.futures.ThreadPoolExecutor.map
    o process_map <= concurrent.futures.ProcessPoolExecutor.map
    + add itertools module (#225) stub
    o product
  * add & update tests
  * add & update documentation
    + README
    + examples/
  * update CI framework
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Remove unneeded python2 ipython-related testing dependencies.
  These packages are no longer available for python2 and the test
  suite will automatically skip them if they aren't available.
* Sun Jan  5 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 4.41.1:
  * fix batch_size=None
  * keras missing pop('size')
* Sun Dec 29 2019 Arun Persaud <arun@gmx.de>
- update to version 4.41.0:
  * trim on ncols overflow with ANSI handling (#850, #716 <- #690)
  * add notebook.reset() (#864)
  * add keras.TqdmCallback (#867 <- #835)
  * documentation updates
    + document newly added features (above)
    + notebook ncols percentage/pixels (#276)
  * test updates
    + test newly added features (above)
    + add CI for win and osx (#841)
    + py2 threading
* Fri Dec 13 2019 Arun Persaud <arun@gmx.de>
- update to version 4.40.2:
  * fix pandas unhashable func (#862 -> #863)
    + add tests
* Sat Dec  7 2019 Arun Persaud <arun@gmx.de>
- update to version 4.40.1:
  * test for floats for total
- changes from version 4.40.0:
  * officially support float for n and total (#802)
    + notebook: use FloatProgress <= IntProgress (#471, #456)
    + allow imprecision (n <= total + epsilon) (#849)
  * fix unicode bar format arguments (#803 -> #851)
  * add contrib submodule (#815)
  * add wrapattr, utils.CallbackIOWrapper, contrib.DummyTqdmFile (#84
  - > #844)
  * update tests
  * update documentation
  * tidy automatic snap deployments
  * minor doc update (#854)
* Sat Nov 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Don't use RPM internal/reserved name %%suffix (change to
  pkg_suffix).
* Sun Nov 24 2019 Arun Persaud <arun@gmx.de>
- update to version 4.39.0:
  * add pandas builtin operations check (#843 <- #697)
  * avoid unnecessary dedent (#837)
  * remove unneeded bar logic
  * misc code tidy
  * update documentation
    + document default argument overriding (#370)
    + add missing isatty() (#713)
    + update badges
    + add code of conduct
  * update framework
    + clean CI stages
    + update CI default py3.6 => py3.7
    + automate snap releases (#686 <- #685)
* Sat Nov  9 2019 Arun Persaud <arun@gmx.de>
- update to version 4.38.0:
  * support lock_args for e.g. non-blocking intermediate writes (#838
  - > #839)
    + use self.refresh() in more places
    + add and update performance tests
    + support args for TqdmDefaultWriteLock.acquire()
  * fix colorama on win (#678, #764)
  * framework updates
    + CI cleanup
    move to stages (check/test/deploy)
    auto deploy notes
    deploy only on parent repo
    separate docker deploy
    + update documentation sync/generation
  * update examples
  * update documentation
  * add and update tests
  * misc tidy and linting
- changes from version 4.37.0:
  * potential future pandas fix (#824)
  * better unicode widechar support (#803 -> #410, #805)
  * fix example/tqdm_wget unknown total (#826)
  * add stacklevel=2 to warnings (#821)
  * misc framework updates
    + snapcraft version fix
    + update issue/pr templates (#830)
    + update unit tests
  * misc documentation updates
    + update parallel (multiprocessing, ThreadPoolExecutor) example
    (#407)
    + add slides, video images
    + add CII Best Practices badge
    + add repology badge
    + update badge icons
* Sat Sep 21 2019 Arun Persaud <arun@gmx.de>
- update to version 4.36.1:
  * fix CLI entrypoint
- changes from version 4.36.0:
  * expose more custom format params
  * potential thread safety fix (#548)
  * update submodule architecture (#198 -> #800)
    + backward-compatibility
    + expose utils
    + rename main -> cli
    + add/fix tests
    + fix minor cached var optimisation
    + gui partial upgrade (#790)
    + notebook upgrade (#790)
    support {bar} in bar_format (#594)
    inherit methods including set_*(refresh) (#740 -> #741)
    + ready for contrib releases (#252)
  * support custom bar_format with unknown total
  * fix tqdm_notebook red block on explicit file=None (#791)
  * update notebook to fully support custom bar_format (#594, #649)
  * misc tidy
    + warnings
    + linting
    + update submodule contribution guide (#252)
    + parallel (py)make test
    + fix Zenodo metadata
  * update documentation
    + pandas, notebook, gui (#245)
    + indentation
    + update multiprocessing and multithreading examples (#796)
* Sun Aug 25 2019 Arun Persaud <arun@gmx.de>
- update to version 4.35.0:
  * add {bar} format specifier (#623 -> #799)
    [width][type]
  * add tests and documentation
  * update performance tests
- changes from version 4.34.0:
  * add leave=None convenience option for leave = position == 0
  * ensure nested completed bars respect leave=True (#230)
  * ensure nested bars are cleared before being moved up (#795)
  * support both and = syntax for CLI options (#761 -> #774)
  * misc documentation updates (#778, #782)
  * fix/update tests
  * update GitHub docker package deployment
* Fri Aug  9 2019 Todd R <toddrme2178@gmail.com>
- update to version 4.33.0:
  * fix pandas==0.25 API change
  * add contributor badges (sourcerer)
  * fix py26 travis CI
  * metadata fixes
    > .zenodo.json
    > CODEOWNERS
  * GitHub package registry docker deployment
  * minor linting
  * documentation updates
* Mon Jun 24 2019 Arun Persaud <arun@gmx.de>
- update to version 4.32.2:
  * fix 'Set changed size during iteration' (#481 -> #700, #754)
  * add tqdm.autonotebook check for $VSCODE_PID (#747 -> #751)
  * fix missing multiprocessing in Jython (#698)
  * make bool(tqdm(iter)) consistent with bool(iter) (#353 -> #694)
  * add and update unit tests
  * add and update documentation & framework
    + update notable contributors list
    + update usage docstrings (#714, #715)
    + add funding
    + add awesome-python badge
    + trove classifier update
    + update demo notebook badges
    + add JOSS DOI
    + add Zenodo metadata
    + move unnecessary root clutter
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.32.1
  * fix notebook with unknown total
- Update to 4.32.0
  * support unit_scale in notebook
  * support negative update (#432, #545)
  * add reset() function (#547, #545)
  * add [python setup.py] make run
- Fix jupyter dependencies.
* Sat Feb 16 2019 Arun Persaud <arun@gmx.de>
- update to version 4.31.1:
  * fix file.encoding==None caused by #598 (#673 -> #676)
    + add tests
  * tidy code, update authors and tests
    + add setup.py test to CI
- changes from version 4.31.0:
  * Write bytes to stdout/stderr in py2
    (https://bugs.python.org/issue21363, #589 -> #598)
    + Add write_bytes parameter for py2/3 default override
  * support custom bar characters vias ascii parameter (#223 -> #227)
    + implement, document and test custom bar spinners
  * support custom bar_format with unknown total (#282 -> #284)
  * fix TypeError when unit_scale and unknown total
  * document format_dict
  * expose elapsed_s, remaining_s to bar_format
  * add unit option to bar_format (#368)
  * auto README.rst generation framework
    + add notes in CONTRIBUTING.md
  * update tests
  * update documentation
  * misc code tidy
- changes from version 4.30.0:
  * avoid moving when leave=False
  * generalise nested bar tests
  * add display() helper function
  * add and expose format_dict (#562, #482, #494, #656)
    + allow arbitrary keyword arguments for format_meter
    + document format_dict overriding
    + add tests for overriding
    + related: #660 #172 #587
  * add and tidy developer documentation
  * fix py3 CLI pipe decoding error (#663)
  * framework overhaul (developing, testing, Travis CI updates)
  * tidy code and style (flake8)
  * setup.py refactor
    + setup.py make
  - add support for multi-line commands
  - tidy and efficiency
    + replace setup.py's built-in make -> py-make>=0.1.9 (#290)
    + add requirements-dev.txt and extras_require[dev]
  * add, update and tidy tests
  * include interactive Jupyter demonstration (#652 -> #659)
  * update documentation
    + add FAQ about py2 pipes (#359)
    + add badges
    + update examples
    + update authors
- changes from version 4.29.1:
  * fix classmethod lock bug (#617: #457 -> #658)
  * add unit test to prevent regression
- changes from version 4.29.0:
  * Avoid global multiprocessing locks (#611 -> #617)
  * Add support for infinite iterables (#651)
  * Fix missing attr pos when used in multi-threaded environment
    (#573)
  * Do not join TMonitor if it is the current thread (#613 -> #641)
  * Add OpenBSD NIX support (#638)
  * Unit tests, general documentation fixes and tidying (e.g. #642)
  * CI travis improvements
    + py37-dev -> py37 (#622)
    + fix py26
* Tue Feb 12 2019 Matej Cepl <mcepl@suse.com>
- Remove installed files after running the testsuite
* Sat Feb  9 2019 Matej Cepl <mcepl@suse.com>
- Switch to multibuild (with separate test) to avoid large
  dependencies on the main package.
* Mon Dec 31 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 4.28.1:
  * tqdm.main(): expose argv
  * cli: add working `--manpath`
  * fix CLI:--manpath not found issue
  * update .gitattributes
  * CLI unit tests
  * remove deprecated dist options
  * add missing auto submodule
  * PyPI fix
  * remove man page from distribution
  * cli:add `--man_path` option
* Wed Oct 17 2018 Arun Persaud <arun@gmx.de>
- update to version 4.27.0:
  * fix str.isnumeric #605
  * fix WeakSet KeyError #548, #553, #596 -> #607
  * stop tqdm_notebook description truncation #582 -> #599
  * include unit_scale for rate #608
  * add auto -> nowarning autonotebook
  * add better postfix numeric formatting #621
  * minor refactoring #609 -> #616
  * update documentation
  * add unit tests
  * fix py26 CI
* Sun Sep 16 2018 Arun Persaud <arun@gmx.de>
- update to version 4.26.0:
  * fix smoothing (#566 -> #601)
  * pandas updates
    + address the FutureWarning in pandas, drop pandas test in py34,
    add in py37 (#603)
    + support pandas axis='index' or 'columns' (#570)
  * minor documentation updates (#597, #600, #606)
    + developer notes
* Tue Aug 28 2018 tchvatal@suse.com
- Reenable testsuite
* Sat Aug 25 2018 arun@gmx.de
- specfile:
  * remove devel for noarch package
  * make %%files section more specific
- update to version 4.25.0:
  * stop monitor on shutdown (#571, #572)
  * fix find_packages() for submodules (#593)
    + properly add autonotebook (#586, 1cf3393)
  * ignore ANSI escape codes in the bar length calculation (#450, #591
  - > #592)
  * update documentation (#243)
* Tue Aug  7 2018 toddrme2178@gmail.com
- update to 4.24.0
  * autonotebook submodule for automatic selection of notebook/CLI bar (#443, #508)
    > update/add pandas() example documentation (#474)
  * NameError:IntProgress changed to a more helpful ImportError (#187, #451, #558)
  * support bool() cast when disable=True (#574)
  * fix format_sizeof hundreds rounding (#579 -> #581)
  * ensure URLs in documentation are secure (https)
* Sat Jul 14 2018 arun@gmx.de
- specfile:
  * removed patch support_pandas_23_groupby.patch (included upstream)
  * always run tests
- update to version 4.23.4:
  * Support pandas 0.23.0 core.groupby module layout (#555 -> #554)
  * Add python_requires to help pip (#557)
  * minor maintenance updates
    + CI updates: drop travis py33 due to tox (tox-dev/tox#648)
    + minor code tidy
* Thu May 17 2018 toddrme2178@gmail.com
- update to version 4.23.3
  * suppress warning
  * update .github things
- update to version 4.23.2
  * minor import syntax fix #496
  * re-fix nested overlaps #477
  * update documentation and examples
  * code tidy and abstraction
- update to version 4.23.1
  * fix AttributeErrors (#546)
    >   pos on initialisation (#323, #510 -> #544)
    >   fp on write() (#383)
  * fix py34 CI
  * update documentation
- update to version 4.23.0
  * Fix disable=True whereiterable has no len() and is not None (#539)
  * Add ncols to specify tqdm_notebook bar width (#276 -> #292)
  * allow custom pandas total (#364 -> #535)
  * Add progress_apply for pandas.(Series|DataFrame).(rolling|expanding) (#530 -> #537)
  * unit tests, pep8 tidy
  * postfix non-dict documentation note
- update to version 4.22.0
  * allow direct non-string assignment to postfix member (lists, dicts, etc) (#382 -> #534)
  * documentation updates
  * unit tests
- update to version 4.21.0
  * fix #532 write() with manual position
    >   more robust free position finding
  * add TqdmWarning base class
  * fix GUI __del__()
    >   add TqdmExperimentalWarning
  * add, tidy & fix unit tests
  * documentation
    >   wiki release notes
    >   update contributors
    >   fix 7zx example
- update to version 4.20.0
  * pandas wrapper: remove *args and add better total handling (#244, #299, #322, #366 -> #524)
  * document windows unicode know issues (#454)
  * suppress RuntimeError: Set changed size during iteration -> TqdmSynchronisationWarning
- update to version 4.19.9:
  * fix monitor thread termination and update tests
- Add support_pandas_23_groupby.patch
  * Fix for pandas 0.23.0 support
  * See: https://github.com/tqdm/tqdm/pull/554
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.8:
  * TqdmMonitorWarning
  * warnings.warn
  * log.info
  * abstract and no-raise monitor error
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.7:
  * fix: Avoid manipulating uninitialized instances on monitoring
    thread.
* Thu Mar  1 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.19.6:
  * CLI improvements
    + --bytes implies --unit B --unit_scale --unit_divisor 1024 (#503)
    + allow hyphens in CLI arguments (#511)
  * synchronisation: fix for sem_open on aarch64 (#513)
  * framework update
    + CI/tests, year 2018, py37, badges, documentation
* Sun Dec 10 2017 arun@gmx.de
- update to version 4.19.5:
  * multiprocess/lock fixes (#457)
  * set_description in notebook (#345 -> #475)
  * minor tidy (#476)
  * documentation updates
* Sun Oct 15 2017 arun@gmx.de
- update to version 4.19.4:
  * fix Lock:NotImplementedError on certain systems (#466 -> #468)
  * use recursive locks (#469 -> #468)
    + fix deadlocks
  * tidy (#448)
  * flush() on moveto() (#398 -> #399, #420, #467)
  * update tests and benchmarks
- changes from version 4.19.3:
  * no changelog available
* Tue Oct 10 2017 arun@gmx.de
- specfile:
  * added man page, fixed path for man-page in setup.py
  * added fdupes
- update to version 4.19.2:
  * flush() on refresh() (#459 from #317)
  * status printer updates (#331)
    + use sp() in refresh()
    + remove redundant clear():nomove=False
  * misc minor documentation updates
  * unit tests
- changes from version 4.19.1:
  * rate_(no)inv(_fmt) (#72, b228bc3)
  * __repr__() tidy (#389)
  * fix write() before initialisation AttributeError: _lock (#457)
  * man pages
  * documentation updates
* Fri Oct  6 2017 jengelh@inai.de
- Redo description with sensible content.
* Tue Oct  3 2017 arun@gmx.de
- update to version 4.18.0:
  * Thread safety! (#285 -> #291 -> #329, #407, #417)
  * Ease redirection of sys.stdout/stderr (#422)
  * Minor internal stream bugfix (#439)
  * AttributeError fixes (#323, #324, #418)
  * Related to:
    + Misc bugs (#334)
    + concurrent.futures (#97)
    + Multi-tqdm (#143)
    + flush() and refresh() (#331)
    + Newline on refresh() (#361)
    + Nested trees (#384)
    + Manually positioned nested bars clearing (#385)
* Sun Sep 24 2017 arun@gmx.de
- update to version 4.17.1:
  * __repr__() bugfix
  * better unicode detection
  * initialise `n` even when disabled
- changes from version 4.17.0:
  * easier redirect of stdout (#426 -> #431)
    + cls.external_write_mode() @contextmanager
  * refresh=True for set_description/update(_str) (#317 -> #377)
- changes from version 4.16.0:
  * more formatting control (#347 -> #362)
    + set_postfix_str(), set_description_str()
    + move ": " to bar_format
    + complements #266, #270
  * better CLI support (e.g. hyphenated paths) (#421 #423 -> #424)
  * more unit tests (#411)
    + upgrade to pypy2/3-5.8.0
    + add py37-dev
  * doc updates
- changes from version 4.15.0 :
  * minor fixes (#395)
  * minor documentation updates (#400, #401, #412)
  * better pandas support (#351 -> #409)
  * Jupyter notebook fix (#352, #369 -> #373, #405)
  * optimise setcheckinterval/setswitchinterval (#376)
  * add unit_scale (#273, #295 -> #378)
* Wed Jul  5 2017 sebix+novell.com@sebix.at
- upgrade specfile to singlespec
- upgrade to 4.14.0
* Wed Mar  1 2017 toddrme2178@gmail.com
- Update to 4.11.2
  * thread safety #332
  * address DeprecationWarning #319 -> #326
  * version extra #328 -> #330
    + security fix
    + add non-master branch name
    + Fixes BNC#1017485
    + Fixes CVE#CVE-2016-10075
  * minor safety
  * minor documentation and comments
- Update to 4.11.1
  * Officially support Python 3.6, addressing #333
- Update to 4.11.0
  * postfix argument added #266->#270
  * fix tests for
    + numpy #272->#302
    + PyPy3 #318->#325
  * 7z extraction example script
  * new logo #315
  * hit counter with logo colours and stats
  * documentation updates
  * safer setup.py Makefile emulation
  * better github contributions integrations and Code of Conduct #310
- update to version 4.10.0:
  * fix maxinterval to adjust miniters to mininterval #249
  * minor bugfixes (eg #288)
  * misc optimisations, unit tests, and benchmarks (eg #298)
  * documentation updates
- update to version 4.9.0:
  * monitoring thread to automatically to adjust miniters and avoid
    exceeding maxinterval
    + test race conditions
    + kill on KeyboardInterrupt + instant refresh
    + low performance overhead, option to disable
  * new CLI argument: --bytes to count chars
  * disable automatically on non-TTY (#281)
  * fixed refresh() and clear() if disabled (#286)
  * misc fixes
  * documentation
  * unit tests
  * optimisations, style fixes
  * codacy badge
  * safety and warning suppression
  * ignore coverall failures (#283)
  * fix broken link in README (#262)
  * Fix time() in refresh() + avoid write() races (#264)
  * Fix __repr__() #269
  * Fix update(0) causing ZeroDivisionError (on first call) #268
  * Faster simple bar for perf test (#257)
  * cleaner tqdm_notebook exit when not run in a notebook (#267)
  * Disable coveralls because of duplicate comments on github (#263)
  * Migrate codecov config -> codecov.yml
* Mon Sep 19 2016 toddrme2178@gmail.com
- update to version 4.8.4:
  * 14%% overhead reduction
  * fix exception when closing tqdm_notebook without a total
  * support more pandas modules
  * pandas.Series.progress_map
  * pandas.DataFrame.progress_applymap
  * Panel.progress_apply
  * PanelGroupBy.progress_apply
  * GroupBy.progress_aggregate
  * GroupBy.progress_transform
  * faster CI builds
  * misc documentation update and link to wiki
- update to version 4.8.3:
  (no changelog available)
- update to version 4.8.2:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.1:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.0:
  * tqdm.pandas classmethod replaces tqdm_pandas function (deprecated)
  * ipython aliased imports fixes
  * write without any instances
  * readme update
  * examples update
  * test fixes and updates
- update to version 4.7.6:
  * numpy len support, addressing #185
- update to version 4.7.5:
  * spring clean (mostly pragma)
  * addresses #182
  * series len, tests
  * disable support (fixes #184), fkake8 fixes
- update to version 4.7.4:
  * pandas.DataFrame.apply support
  * tqdm_notebook.write()
  * tqdm_gui.write()
  * misc notebook fixes
  * delay notebook imports (>80%% reduction in import time when unused)
  * optional colorama only on windows
  * documentation tidy
  * more & faster tests
- update to version 4.7.1:
  * pandas.DataFrame.apply support
- update to version 4.7.0:
  * CLI custom delimiter support
  * More robust CLI argument parsing
  * either one or two - preceding kwargs (eg -ascii or --ascii)
  * no positional args (so no need to quote multi-word -desc for
    example)
  * bool kwargs with implicit value=True still supported
  * optional = sign after kwargs
  * tests
  * doc updates, badges
  * pyversions, doi, licence, github
- update to version 4.6.2:
  * Fix warnings due to IPython/Jupyter widget
- update to version 4.6.1:
  * add IPython/Jupyter support
  * fix {bar} length breaking display when using custom bar_format
  * add a no inversion rate formatting for bar_format (i.e., always
    show it/s and never s/it)
- update to version 4.6.0:
  * (no changelog availabel)
- update to version 4.5.0:
  * print messages within (nested) loops using tqdm.write(...)
- update to version 4.4.3:
  * remove docopt dependency for CLI
  * re-added update(0) ability to trigger refresh
  * minor fixes
  * re-added (OSI approved) licence to source
  * dev versioning auto-fallback
  * slight speed optimisation
  * tests
  * documentation
- update to version 4.4.2:
  * no changelog available
- update to version 4.4.1:
  * remove "dumb binaries" from build, coverage
- update to version 4.4.0:
  * modularise
- update to version 4.3.0:
  * fix_position
  * tidy
- update to version 4.2.0:
  * licencizors
- update to version 4.1.0:
  * compat-fixes
- update to version 4.0.0:
  * automate nested
    + deprecate nested
    + add manual override control with position
  * documentation and example updates, coverage and tests
  * make leave==True by default (was False)
* Mon Feb  1 2016 arun@gmx.de
- update to version 3.8.0:
  * update(n<1) raises error
  * sanitise and update examples and README
  * fix setup.py encoding error
  * remove py32 from Travis
  * changelog more accessible from README
* Wed Jan 20 2016 toddrme2178@gmail.com
- Initial version
